@@ -54,7 +54,6 @@ class Device:
         self.make = None
         self.model = None
         self.license_plate = license_plate
-        self.friendly_name = None
         self.chassisnumber = None
         self.startdate = None
         self.year = None
@@ -75,6 +74,11 @@ class Device:
         """Format the license plate so it can be used as identifier."""
         return self.license_plate.replace("-", "")
 
+    @property
+    def friendly_name(self):
+        """Compose a friendly name."""
+        return f"{self.license_plate} {self.make} {self.model}"
+
     @property
     def state_attributes(self):
         """Return all attributes of the vehicle."""
@@ -136,7 +140,6 @@ class Device:
                 when = datetime.datetime.fromtimestamp(trip[-1]["endDate"])
                 self.last_seen = when.strftime("%Y-%m-%d %H:%M:%S")
 
-        self.friendly_name = f"{self.license_plate} {self.make} {self.model}"
 
     def get_odometer(self, object_id: str, date=None) -> dict:
         """Get odometer readings."""
